==> hs-monad-control-0.3.1.tbz: lib/ghc-7.0.4/cabal/monad-control-0.3.1/register.sh <==
#!/bin/sh
echo 'name: monad-control
version: 0.3.1
id: monad-control-0.3.1-1333e5139f968161c6bcc52cc61cd68b

license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
stability:
homepage: https://github.com/basvandijk/monad-control
package-url:
description: This package defines the type class @MonadBaseControl@, a subset of
             @MonadBase@ into which generic control operations such as @catch@ can be
             lifted from @IO@ or any other base monad. Instances are based on monad
             transformers in @MonadTransControl@, which includes all standard monad
             transformers in the @transformers@ library except @ContT@.
             .
             See the @lifted-base@ package which uses @monad-control@ to lift @IO@
             operations from the @base@ library (like @catch@ or @bracket@) into any monad
             that is an instance of @MonadBase@ or @MonadBaseControl@.
             .
             Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
             library. The main difference is that this package provides CPS style operators
             and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
             simplify and speedup most definitions.
             .
             The following @critertion@ based benchmark shows that @monad-control@ is on
             average about 99% faster than @monad-peel@:
             .
             @git clone <https://github.com/basvandijk/bench-monad-peel-control>@
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules: Control.Monad.Trans.Control
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/monad-control-0.3.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/monad-control-0.3.1
              /usr/local/lib
hs-libraries: HSmonad-control-0.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         base-unicode-symbols-0.2.2.3-7046c6ff08b9eb3d5c83f899d1ba353f
         transformers-0.2.2.0-7341f4d82874561a0431f4b264319cf8
         transformers-base-0.4.1-a4a9a2431fc06f88abe0bc79f3ce7ed4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/monad-control-0.3.1/html/monad-control.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/monad-control-0.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-monad-control-0.3.1.4_1.tbz: lib/ghc-7.4.2/cabal/monad-control-0.3.1.4/register.sh <==
#!/bin/sh
echo 'name: monad-control
version: 0.3.1.4
id: monad-control-0.3.1.4-1d52a0e52c2ed35102613ba7d521f3af

license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
stability:
homepage: https://github.com/basvandijk/monad-control
package-url:
synopsis: Lift control operations, like exception catching, through monad transformers
description: This package defines the type class @MonadBaseControl@, a subset of
             @MonadBase@ into which generic control operations such as @catch@ can be
             lifted from @IO@ or any other base monad. Instances are based on monad
             transformers in @MonadTransControl@, which includes all standard monad
             transformers in the @transformers@ library except @ContT@.
             .
             See the @lifted-base@ package which uses @monad-control@ to lift @IO@
             operations from the @base@ library (like @catch@ or @bracket@) into any monad
             that is an instance of @MonadBase@ or @MonadBaseControl@.
             .
             Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
             library. The main difference is that this package provides CPS style operators
             and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
             simplify and speedup most definitions.
             .
             The following @criterion@ based benchmark shows that @monad-control@ is on
             average about 99% faster than @monad-peel@:
             .
             @git clone <https://github.com/basvandijk/bench-monad-peel-control>@
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules: Control.Monad.Trans.Control
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/monad-control-0.3.1.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/monad-control-0.3.1.4
              /usr/local/lib
hs-libraries: HSmonad-control-0.3.1.4
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         base-unicode-symbols-0.2.2.4-5e2b84bb0750865af1276498a03dd32a
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
         transformers-base-0.4.1-9023dccd35c525f9deca7e00af9540a5
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/monad-control-0.3.1.4/html/monad-control.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/monad-control-0.3.1.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
